import torch

from transformers import AutoModelForCausalLM
from datasets import load_dataset
from transformers import Trainer, TrainingArguments


class FineTune:
    def __init__(self) -> None:
        pass

    def launch(
        self,
        *,
        dataset: str,
        model: str,
        epoch: int = 1,
        batch_size: int = 8,
        learning_rate: float = 0.00001,
        output_dir: str = "",
    ):

        model = AutoModelForCausalLM.from_pretrained(
            model, torch_dtype=torch.bfloat16, device_map="auto"
        )

        train_dataset = load_dataset(dataset, split="train")

        training_args = TrainingArguments(
            output_dir=output_dir,
            num_train_epochs=epoch,
            learning_rate=learning_rate,
            per_device_train_batch_size=batch_size,
        )

        trainer = Trainer(
            model=model,
            args=training_args,
            train_dataset=train_dataset["input"],
        )

        trainer.train()

        trainer.save_model(output_dir)
        return



# coding: utf-8

import io
import os

from setuptools import setup, find_packages

REQUIRES = [
    "transformers>=4.42.0",
    "datasets",
    "accelerate>=0.33,<1.0.0",
    'typing>=3.6.4,<4.0.0; python_version<"3.5"',
]


dir = os.path.abspath(os.path.dirname(__file__))


about = {}
with io.open(os.path.join(dir, "__version__.py")) as f:
    exec(f.read(), about)


setup(
    name="yotta-labs",
    version=about["__version__"],
    long_description_content_type="text/markdown",
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    install_requires=REQUIRES,
    python_requires=">=3.8",
    include_package_data=True,
    packages=find_packages()
)
